import itertools
import sys
import math

def euclidean_distance(p1, p2):
    """Вычисляет евклидово расстояние между двумя точками p1 и p2."""
    return math.sqrt((p1[0] - p2[0]) ** 2 + (p1[1] - p2[1]) ** 2)

def total_distance(points, order):
    """Вычисляет общую длину маршрута для заданного порядка посещения точек."""
    distance = 0
    for i in range(len(order) - 1):
        distance += euclidean_distance(points[order[i]], points[order[i + 1]])
    return distance

def main():
    input = sys.stdin.read
    data = input().splitlines()
    n = int(data[0])
    points = [tuple(map(int, line.split())) for line in data[1:n + 1]]

    # Генерируем все возможные порядки посещения адресов
    orders = itertools.permutations(range(n))

    # Находим минимальное расстояние среди всех порядков
    min_length = float('inf')
    for order in orders:
        length = total_distance(points, order)
        if length < min_length:
            min_length = length

    print(f"{min_length:.12f}")

if __name__ == "__main__":
    main()
